==> migrate_wizard-2.0.8-alpha1.tar.gz: migrate_wizard/src/Form/MWDatabaseField.php <==
<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\migrate_wizard\MWConfigBuilder;
use Drupal\migrate_wizard\MWManageDataService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure migrate_wizard.
 */
class MWDatabaseField extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected $mwManageDataService;

  /**
   * {@inheritdoc}
   */
  protected $mwConfigBuilder;

  /**
   * {@inheritdoc}
   */
  protected $id;

  /**
   * {@inheritdoc}
   */
  protected $database_fields;

  /**
   * {@inheritdoc}
   */
  protected $migrate_wizard_settings;

  /**
   * {@inheritdoc}
   */
  protected $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  public function __construct(MWManageDataService $mw_manage_data_service, EntityTypeManagerInterface $entity_type_manager) {
    $this->mwManageDataService = $mw_manage_data_service;
    $this->entityTypeManager = $entity_type_manager;
    $this->database_fields = ['id', 'migration_group', 'key', 'target', 'host', 'database', 'username', 'password', 'prefix', 'driver', 'port', 'namespace', 'collation', 'url_files_prod'];
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new self(
      $container->get('migrate_wizard.migrate_wizard_manage_data_service'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'manage_mw_database_fields';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['migrate_wizard.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, string $id = NULL) {

    $this->id = $id;
    $entity = $this->entityTypeManager->getStorage('mw_database')->load($id);

    //add checkbox
    $form['use_env'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Use .env'),
      '#default_value' => $entity->use_env,
    ];
    foreach($this->database_fields as $database_field){
        $form[$database_field] = [
          '#type' => 'textfield',
          '#title' => t($database_field),
          '#size' => '20',
          '#default_value' => $entity->$database_field,
        ];
      if($database_field == 'id'){
        $form[$database_field]['#disabled'] = TRUE;
      }
    }

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
    ];
    //add delete
    $form['delete'] = [
      '#type' => 'submit',
      '#value' => $this->t('Delete'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {}

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    //get triggering element
    $triggering_element = $form_state->getTriggeringElement();

    if($triggering_element["#id"] != 'edit-delete'){

      $user_inputs = $form_state->getUserInput();
      $entity = $this->entityTypeManager->getStorage('mw_database')->load($this->id);

      $entity->set('use_env', $user_inputs['use_env']);
      foreach($this->database_fields as $database_field){
        if($database_field != 'id'){
          $entity->set($database_field, $user_inputs[$database_field]);
        }
      }
      $entity->save();
    }else{
      $entity = $this->entityTypeManager->getStorage('mw_database')->load($this->id);
      $entity->delete();
    }
    $form_state->setRedirect('entity.database.list');
  }

  /**
   * {@inheritdoc}
   */
  public function getTitle($type = null): \Drupal\Core\StringTranslation\TranslatableMarkup
  {
    return $this->t('Edit MW Database');
  }
}

==> migrate_wizard-2.0.9-alpha1.tar.gz: migrate_wizard/src/Form/MWDatabaseField.php <==
<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Form;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\migrate_wizard\MWManageDataService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure migrate_wizard.
 */
class MWDatabaseField extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected $database_fields;

  /**
   * {@inheritdoc}
   */
  protected $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  protected $id;

  /**
   * {@inheritdoc}
   */
  protected $migrate_wizard_settings;

  /**
   * {@inheritdoc}
   */
  protected $mwConfigBuilder;

  /**
   * {@inheritdoc}
   */
  protected $mwManageDataService;

  /**
   * {@inheritdoc}
   */
  public function __construct(MWManageDataService $mw_manage_data_service, EntityTypeManagerInterface $entity_type_manager) {
    $this->mwManageDataService = $mw_manage_data_service;
    $this->entityTypeManager = $entity_type_manager;
    $this->database_fields = ['id', 'migration_group', 'key', 'target', 'host', 'database', 'username', 'password', 'prefix', 'driver', 'port', 'namespace', 'collation', 'url_files_prod'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, ?string $id = NULL) {
    $this->id = $id;
    $entity = $this->entityTypeManager->getStorage('mw_database')->load($id);

    // add checkbox
    $form['use_env'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Use .env'),
      '#default_value' => $entity->use_env,
    ];

    foreach ($this->database_fields as $database_field) {
      $form[$database_field] = [
        '#type' => 'textfield',
        '#title' => $this->t($database_field),
        '#size' => '20',
        '#default_value' => $entity->$database_field
      ];

      if ($database_field === 'id') {
        $form[$database_field]['#disabled'] = TRUE;
      }
    }

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
    ];
    // add delete
    $form['delete'] = [
      '#type' => 'submit',
      '#value' => $this->t('Delete'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new self(
      $container->get('migrate_wizard.migrate_wizard_manage_data_service'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'manage_mw_database_fields';
  }

  /**
   * {@inheritdoc}
   */
  public function getTitle($type = NULL): \Drupal\Core\StringTranslation\TranslatableMarkup {
    return $this->t('Edit MW Database');
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    // get triggering element
    $triggering_element = $form_state->getTriggeringElement();

    if ($triggering_element['#id'] !== 'edit-delete') {
      $user_inputs = $form_state->getUserInput();
      $entity = $this->entityTypeManager->getStorage('mw_database')->load($this->id);

      $entity->set('use_env', $user_inputs['use_env']);

      foreach ($this->database_fields as $database_field) {
        if ($database_field !== 'id') {
          $entity->set($database_field, $user_inputs[$database_field]);
        }
      }
      $entity->save();
    }
    else {
      $entity = $this->entityTypeManager->getStorage('mw_database')->load($this->id);
      $entity->delete();
    }
    $form_state->setRedirect('entity.database.list');
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {}

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['migrate_wizard.settings'];
  }

}
